@@ -23,6 +23,7 @@ export const messages: { [messageId: string]: MessageType } = {
   aboutDialogDocumentationText: 'Documentation',
   aboutDialogReportIssuesLink: 'Please report issues on {link}',
   aboutDialogVersion: 'Version {version}',
+  accountSettings: 'Account Settings',
   actionFailed: '{action} failed',
   actionFeedbackShutdownVm: 'Request to shutdown VM - {VmName} has been received.',
   actionFeedbackRestartVm: 'Request to restart VM - {VmName} has been received.',
@@ -58,16 +59,17 @@ export const messages: { [messageId: string]: MessageType } = {
   bootMenuWarning: 'All changes will take effect after reboot only.',
   bootOrder: 'Boot Order',
   bootSequence: 'Boot Sequence',
-  bootSequenceTooltip: 'Device order in which VM will search OS for running.',
   cancel: 'Cancel',
   cannotUpdateCloudInitHostname: 'Host name cannot be synchronized with VM name because the VM name is not a valid host name.',
   cantLogonToConsole: 'Single sign on failed. Please check to see if the guest agent is running on your virtual machine. Contact your administrator if the problem continues.',
   cardTitleDetails: 'Details',
-  cardTooltipEditDetails: 'Edit details for {vmName}',
   cd: 'CD',
-  cdCanOnlyChangeWhenVmRunning: 'CD can only be changed when the VM is running',
+  cdCanOnlyChangeWhenVmRunning: 'CD can only be changed when the VM is running.',
   cdromBoot: 'CD-ROM',
-  changeCd: 'Change CD',
+  changesSavedSuccesfully: {
+    message: 'Changes to settings saved succesfully!',
+    description: 'Message displayed when all user settings have been saved successfully',
+  },
   clear: 'Clear',
   clearAll: 'Clear all',
   clearAllFilters: 'Clear All Filters',
@@ -170,7 +172,7 @@ export const messages: { [messageId: string]: MessageType } = {
   customIcon: 'Custom icon of the virtual machine.',
   customScript: 'Custom script',
   dataCenter: { message: 'Data Center', description: 'Label for the VM\'s data center' },
-  dataCenterChangesWithCluster: 'Data Center cannot be changed directly. It correlates with the Cluster.',
+  dataCenterChangesWithCluster: 'The data center cannot be edited from here. Please contact your administrator if you would like to edit the data center.',
   daysShort: 'd',
   defaultButton: 'Default',
   definedMemory: 'Defined Memory',
@@ -206,7 +208,7 @@ export const messages: { [messageId: string]: MessageType } = {
   },
   diskEditorResizeLabel: 'Increase Size By (GiB)',
   diskEditorSizeCantChangeHelp: 'Disk size cannot be extended for this type of disk.',
-  diskEditorSizeCreateHelp: 'After you create a disk, you may only extend its size if you make edits.',
+  diskEditorSizeCreateInfoTooltip: 'After creating a disk, you can only extends its size. It is not possible to decrease disk size.',
   diskEditorSizeLabel: 'Size (GiB)',
   diskEditorSizeEditLabel: 'Current Size (GiB)',
   diskEditorResizeNote: `After resizing the disk, you must also increase the size of the guest's filesystem`,
@@ -217,10 +219,12 @@ export const messages: { [messageId: string]: MessageType } = {
   diskStateActiveTooltip: 'Active',
   diskStateInactiveTooltip: 'Inactive',
   diskStateLockedTooltip: 'Locked',
+  diskTooltipStatusMessage: 'Status: {statusInfo}',
   disks: 'Disks',
-  disksCardEditTooltip: 'Edit Disks for {vmName}',
   diskSizeHasToBeAPositiveInteger: 'Disk size has to be a positive integer.',
   displayAll: 'Display all',
+  dontDisturb: 'Do not disturb',
+  dontDisturbFor: 'Do not disturb for',
   downloadVirtManagerMSI: 'Download the MSI from virt-manager.org',
   downloadVVFile: 'Download VV File',
   downloadedSPICE: 'The VV file has been downloaded. Select the file to view the SPICE console on a desktop viewer.',
@@ -232,6 +236,7 @@ export const messages: { [messageId: string]: MessageType } = {
   editDisk: 'Edit Disk',
   editNic: 'Edit NIC',
   editVm: 'Edit the VM',
+  email: 'Email',
   empty: 'Empty',
   emptySnapshotDescription: 'Snapshot description is missing.',
   enterVmDescription: 'Enter VM Description (optional)',
@@ -320,6 +325,10 @@ export const messages: { [messageId: string]: MessageType } = {
     description: 'VM is not responding. One of states of a virtual machine. Other are e.g. Up, Down, Powering-Up',
   },
   errorWhileCreatingNewDisk: 'Error while creating new disk:',
+  every30Seconds: 'Every 30 seconds',
+  everyMinute: 'Every minute',
+  every2Minute: 'Every 2 minutes',
+  every5Minute: 'Every 5 minutes',
   failedToChangeVmIcon: 'Failed to change VM icon',
   failedToChangeVmIconToDefault: 'Failed to change VM icon to default',
   failedToGetVmConsole: 'Failed to get the VM console',
@@ -332,6 +341,14 @@ export const messages: { [messageId: string]: MessageType } = {
   failedToRetrieveVmDetails: 'Failed to retrieve VM details',
   failedToRetrieveVmDisks: 'Failed to retrieve VM disks',
   failedToRetrieveVmIcon: 'Failed to retrieve VM icon',
+  failedToSaveChangesToFields: {
+    message: 'Failed to save changes to:',
+    description: 'Some fields have not been saved. List of fields is displayed below in a horizontal list',
+  },
+  failedToSaveChanges: {
+    message: 'Failed to save changes to settings',
+    description: 'No fields have been saved',
+  },
   failedToShutdownVm: 'Failed to shutdown the VM',
   failedToStartVm: 'Failed to start the VM',
   failedToSuspendVm: 'Failed to suspend the VM',
@@ -342,6 +359,7 @@ export const messages: { [messageId: string]: MessageType } = {
   freeBrowsers: 'Free browsers:',
   fullScreen: 'Full Screen',
   fullyQualifiedDomainName: 'Fully Qualified Domain Name (FQDN) of the virtual machine. Please note, guest agent must be installed within the virtual machine to retrieve this value.',
+  general: 'General',
   gitHub: 'GitHub',
   globalErrorBoundaryTitle: 'Sorry, VM Portal is currently having some issues.',
   globalErrorBoundaryDescription: 'Please refresh the page or log out and log back in. If the issue persists, please report a bug on {bugUrl}',
@@ -372,6 +390,7 @@ export const messages: { [messageId: string]: MessageType } = {
   ipAddress: { message: 'IP Address', description: 'Label for IP addresses reported by VM guest agent' },
   isPersistMemorySnapshot: 'Content of the memory of the virtual machine is included in the snapshot.',
   itemDoesntExistOrDontHavePermissions: 'The item doesn\'t exist or you do not have the permissions to view it.',
+  language: 'Language',
   less: {
     message: 'less',
     description: 'more/less pair used to control collapsible long listing',
@@ -428,7 +447,6 @@ export const messages: { [messageId: string]: MessageType } = {
   nextSnapshotsWillBeDeleted: 'Restoring this snapshot will also delete newer snapshots:',
   nic: 'Network interfaces',
   nicActionCreateNew: 'Create NIC',
-  nicCardEditTooltip: 'Edit NICs for {vmName}',
   nicDeleteDisabledTooltip: 'NICs cannot be deleted when the VM is running.',
   nicDeleteTooltip: 'Delete',
   nicEditDisabledTooltip: 'Cannot edit the NIC at this time',
@@ -441,11 +459,13 @@ export const messages: { [messageId: string]: MessageType } = {
   nicEditorLinkStateUp: 'Up',
   nicIP4: { message: 'IPv4', description: 'Label for the IPv4 addresses reported on a Nic' },
   nicIP6: { message: 'IPv6', description: 'Label for the IPv6 addresses reported on a Nic' },
-  nicLinkDownTooltip: 'Link is Down',
-  nicLinkUpTooltip: 'Link is Up',
+  nicLinkStatusUp: 'Link Status: Up',
+  nicLinkStatusDown: 'Link Status: Down',
   nicNoVnicAssigned: 'N/A',
   nicsTooltip: 'Connected VM network interfaces.',
   noActiveStorageDomainInDataCenter: 'There is no active data storage domain in data center "{dataCenterName}"',
+  noCdsAvailable: 'No CDs available',
+  noClustersAvailable: 'No Clusters available',
   noDisks: 'no disks',
   noError: 'No error',
   noMessages: 'There are no notifications to display.',
@@ -465,15 +485,15 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'This field is only available when the VM is running and the guest agent is installed and running.',
     description: 'Tooltip displayed next to \'notAvailable\' for fields that require the VM to be up and a running guest agent',
   },
-  notifications: 'Notifications',
   notEditableForPoolsOrPoolVms: 'Not editable for Pools or pool VMs.',
+  notifications: 'Notifications',
+  notificationSettingsAffectAllNotifications: 'Notification settings applied here affect all notifications (including all VMs and Pools notifications) and are not persisted (a page reload will clear them).',
   noVmAvailable: 'No VM available.',
   noVmAvailableForLoggedUser: 'No VM is available for the logged user.',
   off: 'Off',
   ok: 'OK',
   on: 'On',
   os: 'Operating System',
-  openProtocolConsole: 'Open {protocol} Console',
   operatingSystem: 'Operating System',
   operatingSystemInstalledOnVm: 'Operating system installed on the virtual machine.',
   optimizedFor: 'Optimized For',
@@ -494,7 +514,6 @@ export const messages: { [messageId: string]: MessageType } = {
   },
   publicSSHKey: 'Specify public key for access to guest serial console via SSH authentication.',
   rdpConsole: 'RDP Console',
-  rdpConsoleOpen: 'Open RDP Console',
   reboot: {
     message: 'Reboot',
     description: 'Toolbar button to reboot a VM',
@@ -507,6 +526,8 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'Refresh',
     description: 'Reload data from server',
   },
+  refreshInterval: 'Refresh Interval',
+  refreshIntervalTooltip: 'Interval at which each screen gets refreshed.',
   remoteViewerConnection: 'Remote Viewer Connection',
   remoteViewerAvailable: 'Remote Viewer is available for most operating systems. To install it, search for it in GNOME Software or run the following:',
   remove: 'Remove',
@@ -529,9 +550,9 @@ export const messages: { [messageId: string]: MessageType } = {
   secondDevice: 'Second Device',
   secondDeviceTooltip: 'Second device in order.',
   secondsShort: 's',
+  selectTheBootableDeviceTooltip: 'Select the bootable devices in the order you would like them to boot.',
   sendShortcutKey: 'Send Key',
   sendCtrlAltDel: 'Ctrl+Alt+Del',
-  serviceTip: 'Launch VM service - {serviceName}',
   sessionExpired: {
     message: 'Your session is about to timeout due to inactivity.',
     description: 'Primary message for SessionTimeout modal component',
@@ -544,6 +565,10 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'Size',
     description: '... of disk of virtual machine',
   },
+  sortAToZ: 'Sort from A to Z',
+  sortOffFirst: 'Sorts off machines first',
+  sortRunningFirst: 'Sorts running machines first',
+  sortZToA: 'Sort from Z to A',
   smartcardEnabled: 'Smartcard enabled:',
   snapshot: 'Snapshots',
   snapshotRestore: 'Restore Snapshot',
@@ -552,10 +577,9 @@ export const messages: { [messageId: string]: MessageType } = {
   snapshotsTooltip: 'VM snapshots.',
   sshAuthorizedKeys: 'SSH Authorized Keys',
   sshAuthorizedKeysTooltip: 'New line separated public SSH keys allowing for passwordless remote login.',
-  SSHKey: 'SSH Key',
+  sshKey: 'SSH Key',
+  sshKeyTooltip: 'This public key provides access to the guest serial console via SSH authentication.',
   spiceConsole: 'SPICE Console',
-  spiceConsoleOpen: 'Open SPICE Console',
-  startVm: 'Start the VM',
   startVmOnCreation: 'Start virtual machine on creation',
   state: 'State',
   status: 'Status',
@@ -578,6 +602,7 @@ export const messages: { [messageId: string]: MessageType } = {
   },
   sysPrepCustomScript: 'Custom Script',
   sysPrepTimezone: 'Timezone',
+  sysPrepTimezoneConfigure: 'Configure Timezone',
   sysPrepOptions: 'SysPrep Options',
   takeVm: 'Take a Virtual Machine',
   template: 'Template',
@@ -587,10 +612,13 @@ export const messages: { [messageId: string]: MessageType } = {
   thisOperationCantBeUndone: 'This operation cannot be undone.',
   threadsPerCores: 'Threads per Core',
   totalCountOfVirtualProcessorsVmWillBeEquippedWith: 'Total count of virtual processors the virtual machine will be equipped with.',
-  totalCpuTooltip: 'Total virtual CPUs include {sockets} virtual sockets, {cores} cores per socket, and {threads} thread per core.',
+  totalSocketsCpuTooltipMessage: '{number} virtual sockets',
+  totalCoresCpuTooltipMessage: '{number} cores per socket',
+  totalThreadsCpuTooltipMessage: '{number} threads per core',
   totalMemoryVmWillBeEquippedWith: 'Total memory the virtual machine will be equipped with.',
   troubleWithFindingPage: 'We\'re having trouble finding that page.',
   typeOfWorkloadVmConfigurationIsOptimizedFor: 'Type of workload the virtual machine configuration is optimized for.',
+  uiRefresh: 'UI refresh',
   uniqueNameOfTheVirtualMachine: 'Unique name of the virtual machine.',
   unknown: {
     message: 'unknown',
@@ -608,6 +636,10 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'Dialog contains unsaved changes',
     description: 'Title of modal dialog opened when a user tried to navigate off an editor page after changes have been made.',
   },
+  untilNextPageReload: {
+    message: 'until next page reload',
+    description: 'Phrase used to describe a time period. Will be used in a dropdown (labeled "Do not disturb for") as one of the possible durations (together with typical durations like 1 hour or 1 day).',
+  },
   updateCloudInit: 'Do you want update Cloud-init hostname on new VM name?',
   updateVm: 'Update VM',
   upload: 'Upload',
@@ -656,6 +688,7 @@ export const messages: { [messageId: string]: MessageType } = {
   utilizationNoNetStats: 'Network utilization is not currently available for this VM.',
   useBrowserBelow: 'Please use one of the browsers below.',
   useCtrlAltEnd: 'Use Ctrl+Alt+End',
+  username: 'Username',
   usingRemoteViewer: 'Using a remote viewer relies on a downloaded .vv file.',
   vcpuTopology: 'VCPU Topology',
   viewAllVirtualMachines: 'View All Virtual Machines',
@@ -669,9 +702,7 @@ export const messages: { [messageId: string]: MessageType } = {
   vmType_highPerformance: 'High Performance',
   vmType_server: 'Server',
   vncConsole: 'VNC Console',
-  vncConsoleOpen: 'Open VNC Console',
   vncConsoleBrowser: 'VNC Console (Browser)',
-  vncConsoleBrowserOpen: 'Open VNC Console (Browser)',
   vnicProfile: 'VNIC Profile',
   vnicProfileEmpty: '<Empty>',
   yearsShort: 'y',
